==> mathjax_2.3.orig.tar.gz: MathJax-2.3/unpacked/localization/nl/MathMenu.js <==
/* -*- Mode: Javascript; indent-tabs-mode:nil; js-indent-level: 2 -*- */
/* vim: set ts=2 et sw=2 tw=80: */

/*************************************************************
 *
 *  MathJax/localization/nl/MathMenu.js
 *
 *  Copyright (c) 2009-2013 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

MathJax.Localization.addTranslation("nl","MathMenu",{
        version: "2.3",
        isLoaded: true,
        strings: {
          OriginalMathML: "Oorspronkelijke MathML",
          TeXCommands: "TeX-commando's",
          Annotation: "Annotatie",
          TeX: "TeX",
          StarMath: "StarMath",
          Maple: "Maple",
          texHints: "TeX-hints weergeven in MathML",
          Settings: "Instellingen voor wiskundige formules",
          ZoomTrigger: "Inzoomen als",
          Hover: "Aanwijseffect",
          Click: "Klik",
          NoZoom: "Niet zoomen",
          Option: "Optie",
          Command: "Command",
          Control: "Control",
          Shift: "Shift",
          ZoomFactor: "Zoom factor",
          MPHandles: "Laat MathPlayer de volgende gebeurtenissen afhandelen:",
          MenuEvents: "Menugebeurtenissen",
          MouseEvents: "Muisgebeurtenissen",
          MenuAndMouse: "Muis- en menugebeurtenissen",
          FontPrefs: "Lettertype-voorkeuren",
          ForHTMLCSS: "Voor HTML-CSS:",
          TeXLocal: "TeX (lokaal)",
          TeXWeb: "TeX (web)",
          TeXImage: "TeX (afbeelding)",
          STIXLocal: "STIX (lokaal)",
          Discoverable: "Uitlichten bij aanwijzen",
          Locale: "Taal",
          LoadLocale: "Laden van URL ...",
          Help: "MathJax Help",
          localTeXfonts: "met behulp van lokale TeX-lettertypen",
          webSVGfonts: "met behulp van SVG-weblettertypen",
          genericfonts: "met behulp van standaard Unicodelettertypen",
          wofforotffonts: "WOFF- of OTF-lettertypen",
          eotffonts: "EOT-lettertypen",
          svgfonts: "SVG-lettertypen",
          OperaNativeMMLWarning: "De ondersteuning voor MathML in Opera is beperkt, dus als u overschakelt naar weergave via MathML kunnen sommige expressies slecht worden weergegeven.",
          SafariNativeMMLWarning: "De in uw browser ingebouwde MathML heeft niet alle mogelijkheden die door MathJax worden gebruikt, dus niet alle expressies kunnen correct worden weergegeven.",
          FirefoxNativeMMLWarning: "De in uw browser ingebouwde MathML heeft niet alle mogelijkheden die door MathJax worden gebruikt, dus niet alle expressies kunnen correct worden weergegeven.",
          BadURL: "De URL moet naar een JavaScriptbestand wijzen waarin vertaalgegevens voor MathJax staan. De naam van het JavaScriptbestand moet eindigen op \".js\".",
          PercentScale: "De schaal moet een percentage zijn (bijvoorbeeld 120%%)",
          IE9warning: "Het context menu van MathJax wordt uitgeschakeld, maar u kunt in plaats daarvan door Alt-klikken op een expressie het MathJax menu weergeven.",
          NoOriginalForm: "Geen oorspronkelijke vorm beschikbaar",
          Close: "Sluiten",
          Browser: "Browser",
          Show: "Toon wiskunde als",
          MathMLcode: "MathML code",
          AsciiMathInput: "AsciiMathML invoer",
          Original: "Oorspronkelijke vorm",
          ErrorMessage: "Foutmelding",
          ContentMathML: "Inhoud MathML",
          OpenMath: "OpenMath",
          DoubleClick: "Dubbelklik",
          TriggerRequires: "Trigger vereist:",
          Alt: "Alt",
          Renderer: "Wiskunde weergever",
          Auto: "Automatisch",
          ContextMenu: "Context menu",
          Scale: "Schaal alle wiskunde als ...",
          About: "Over MathJax",
          webTeXfonts: "met behulp van web-lettertype TeX",
          imagefonts: "met behulp van beeld-lettertypes",
          localSTIXfonts: "met behulp van lokale STIX lettertypes",
          WebkitNativeMMLWarning: "Uw browser lijkt MathML niet van origine te ondersteunen, door te kiezen voor MathML uitvoer kan de wiskunde op de pagina onleesbaar worden.",
          MSIENativeMMLWarning: "Internet Explorer vereist de MathPlayer plug-in om MathML uitvoer te verwerken",
          MSIESVGWarning: "SVG is niet ge\u00EFmplementeerd in Internet Explorer versie voor IE9 en ook niet wanneer het IE8 of lager emuleert. Kiezen voor SVG output veroorzaakt onjuiste weergave van de wiskunde.",
          LoadURL: "Laad vertalingsdata van deze URL:",
          BadData: "Vertalingsdata laden van %1 niet gelukt",
          SwitchAnyway: "Evengoed de weergever veranderen?\n\\n\n(Druk op OK om te veranderen, ANNULEREN om door te gaan met de huidige weergever.)",
          ScaleMath: "Schaal alle wiskunde (in vergelijking tot de omliggende tekst) met",
          NonZeroScale: "De schaal zou niet nul moeten zijn",
          IE8warning: "Dit zal het MathJax menu en zoom functies uitschakelen, maar u kunt via Alt-klik op een expressie om het MathJax menu weer te geven.\n\\n\nWilt u inderdaad de MathPlayer instellingen wijzigen?",
          EqSource: "MathJax Vergelijking Bron"
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/nl/MathMenu.js");

==> mathjax_2.4.orig.tar.gz: MathJax-2.4/unpacked/localization/nl/MathMenu.js <==
/* -*- Mode: Javascript; indent-tabs-mode:nil; js-indent-level: 2 -*- */
/* vim: set ts=2 et sw=2 tw=80: */

/*************************************************************
 *
 *  MathJax/localization/nl/MathMenu.js
 *
 *  Copyright (c) 2009-2014 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

MathJax.Localization.addTranslation("nl","MathMenu",{
        version: "2.4.0",
        isLoaded: true,
        strings: {
          Show: "Toon wiskunde als",
          MathMLcode: "MathML code",
          OriginalMathML: "Oorspronkelijke MathML",
          TeXCommands: "TeX-commando's",
          AsciiMathInput: "AsciiMathML invoer",
          Original: "Oorspronkelijke vorm",
          ErrorMessage: "Foutmelding",
          Annotation: "Annotatie",
          TeX: "TeX",
          StarMath: "StarMath",
          Maple: "Maple",
          ContentMathML: "Inhoud MathML",
          OpenMath: "OpenMath",
          texHints: "TeX-hints weergeven in MathML",
          Settings: "Instellingen voor wiskundige formules",
          ZoomTrigger: "Inzoomen als",
          Hover: "Aanwijseffect",
          Click: "Klik",
          DoubleClick: "Dubbelklik",
          NoZoom: "Niet zoomen",
          TriggerRequires: "Trigger vereist:",
          Option: "Optie",
          Alt: "Alt",
          Command: "Command",
          Control: "Control",
          Shift: "Shift",
          ZoomFactor: "Zoom factor",
          Renderer: "Wiskunde weergever",
          MPHandles: "Laat MathPlayer de volgende gebeurtenissen afhandelen:",
          MenuEvents: "Menugebeurtenissen",
          MouseEvents: "Muisgebeurtenissen",
          MenuAndMouse: "Muis- en menugebeurtenissen",
          FontPrefs: "Lettertype-voorkeuren",
          ForHTMLCSS: "Voor HTML-CSS:",
          Auto: "Automatisch",
          TeXLocal: "TeX (lokaal)",
          TeXWeb: "TeX (web)",
          TeXImage: "TeX (afbeelding)",
          STIXLocal: "STIX (lokaal)",
          STIXWeb: "STIX (web)",
          AsanaMathWeb: "Asana Math (web)",
          GyrePagellaWeb: "Gyre Pagella (web)",
          GyreTermesWeb: "Gyre Termes (web)",
          LatinModernWeb: "Latin Modern (web)",
          NeoEulerWeb: "Neo Euler (web)",
          ContextMenu: "Context menu",
          Browser: "Browser",
          Scale: "Schaal alle wiskunde als ...",
          Discoverable: "Uitlichten bij aanwijzen",
          Locale: "Taal",
          LoadLocale: "Laden van URL ...",
          About: "Over MathJax",
          Help: "MathJax Help",
          localTeXfonts: "met behulp van lokale TeX-lettertypen",
          webTeXfonts: "met behulp van web-lettertype TeX",
          imagefonts: "met behulp van beeld-lettertypes",
          localSTIXfonts: "met behulp van lokale STIX lettertypes",
          webSVGfonts: "met behulp van SVG-weblettertypen",
          genericfonts: "met behulp van standaard Unicodelettertypen",
          wofforotffonts: "WOFF- of OTF-lettertypen",
          eotffonts: "EOT-lettertypen",
          svgfonts: "SVG-lettertypen",
          WebkitNativeMMLWarning: "Uw browser lijkt MathML niet van origine te ondersteunen, door te kiezen voor MathML uitvoer kan de wiskunde op de pagina onleesbaar worden.",
          MSIENativeMMLWarning: "Internet Explorer vereist de MathPlayer plug-in om MathML uitvoer te verwerken",
          OperaNativeMMLWarning: "De ondersteuning voor MathML in Opera is beperkt, dus als u overschakelt naar weergave via MathML kunnen sommige expressies slecht worden weergegeven.",
          SafariNativeMMLWarning: "De in uw browser ingebouwde MathML heeft niet alle mogelijkheden die door MathJax worden gebruikt, dus niet alle expressies kunnen correct worden weergegeven.",
          FirefoxNativeMMLWarning: "De in uw browser ingebouwde MathML heeft niet alle mogelijkheden die door MathJax worden gebruikt, dus niet alle expressies kunnen correct worden weergegeven.",
          MSIESVGWarning: "SVG is niet ge\u00EFmplementeerd in Internet Explorer versie voor IE9 en ook niet wanneer het IE8 of lager emuleert. Kiezen voor SVG output veroorzaakt onjuiste weergave van de wiskunde.",
          LoadURL: "Laad vertalingsdata van deze URL:",
          BadURL: "De URL moet naar een JavaScriptbestand wijzen waarin vertaalgegevens voor MathJax staan. De naam van het JavaScriptbestand moet eindigen op \".js\".",
          BadData: "Vertalingsdata laden van %1 niet gelukt",
          SwitchAnyway: "Evengoed de weergever veranderen?\n\\n\n(Druk op OK om te veranderen, ANNULEREN om door te gaan met de huidige weergever.)",
          ScaleMath: "Schaal alle wiskunde (in vergelijking tot de omliggende tekst) met",
          NonZeroScale: "De schaal zou niet nul moeten zijn",
          PercentScale: "De schaal moet een percentage zijn (bijvoorbeeld 120%%)",
          IE8warning: "Dit zal het MathJax menu en zoom functies uitschakelen, maar u kunt via Alt-klik op een expressie om het MathJax menu weer te geven.\n\\n\nWilt u inderdaad de MathPlayer instellingen wijzigen?",
          IE9warning: "Het context menu van MathJax wordt uitgeschakeld, maar u kunt in plaats daarvan door Alt-klikken op een expressie het MathJax menu weergeven.",
          NoOriginalForm: "Geen oorspronkelijke vorm beschikbaar",
          Close: "Sluiten",
          EqSource: "MathJax Vergelijking Bron"
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/nl/MathMenu.js");
